Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(274)

Unified Diff: shell/application_manager/application_manager.h

Issue 1472923002: Allows URL queries to be passed to contet handlers. (Closed) Base URL: https://github.com/domokit/mojo.git@master
Patch Set: Follow review Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: shell/application_manager/application_manager.h
diff --git a/shell/application_manager/application_manager.h b/shell/application_manager/application_manager.h
index 3be49926057b2a9250d979ba1e6b716fa92279fd..f3224f158515871d4c4ec41d287170faa184debd 100644
--- a/shell/application_manager/application_manager.h
+++ b/shell/application_manager/application_manager.h
@@ -178,8 +178,10 @@ class ApplicationManager {
// Creates an Identity for the service identified by |resolved_url|.
// If |new_process_per_connection| is true for the URL's options, then the
// identity is unique. Otherwise, repeated invocations with the same
- // |resolved_url| will result in an equivalent Identity.
- Identity MakeApplicationIdentity(const GURL& resolved_url);
+ // |resolved_url| will result in an equivalent Identity. If |strip_query| is
+ // true, the query is stripped before creating the Identity.
+ Identity MakeApplicationIdentity(const GURL& resolved_url,
+ bool strip_query = true);
mojo::InterfaceRequest<mojo::Application> RegisterShell(
// The URL after resolution and redirects, including the querystring.
« no previous file with comments | « no previous file | shell/application_manager/application_manager.cc » ('j') | shell/application_manager/application_manager.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698